Reference
=========

.. currentmodule:: gql

.. _top-level-functions:

Top-Level Functions
-------------------

.. automodule:: gql

.. _sub-packages:

Sub-Packages
------------

.. toctree::
   :maxdepth: 1

   client
   transport
   transport_aiohttp
   transport_aiohttp_websockets
   transport_appsync_auth
   transport_appsync_websockets
   transport_common_base
   transport_common_adapters_connection
   transport_common_adapters_aiohttp
   transport_common_adapters_websockets
   transport_exceptions
   transport_phoenix_channel_websockets
   transport_requests
   transport_httpx
   transport_websockets
   transport_websockets_protocol
   dsl
   utilities
